@@ -14,7 +14,7 @@ __all__ = [
     'flatten','fname','find','fname2','glob','Glob','inspect','jitter', 'L',
     'line','loaddill','logger','extn', 'makedir', 'np', 'now','nunique','os','pd','pdfilter','parent','Path','pdb',
     'plt','PIL','puttext','randint','rand','read','readlines','readPIL','rect','rename_batch','resize','see',
-    'set_logging_level','show','stem','stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint',
+    'set_logging_level','show','stem','stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint','writelines',
     'Info','Warn','Debug','Excep'
 ]
 
@@ -375,7 +375,7 @@ Blank = lambda *sh: uint(np.ones(sh))
 
 def pdfilter(df, column, condition):
     _df = df[df[column].map(condition)]
-    logger.debug(f'Filtering {len(_df)} items out of {df}')
+    logger.debug(f'Filtering {len(_df)} items out of {len(df)}')
     return _df
 def pdsort(df, column, asc=True):
     df.sort_values(column, ascending=asc)
@@ -410,6 +410,18 @@ def readlines(fpath):
         lines = [l.strip() for l in lines if l.strip()!='']
         Info(f'loaded {len(lines)} lines')
         return lines
+
+def writelines(lines, file):
+    makedir(parent(file))
+    failed = []
+    with open(file, 'w') as f:
+        for line in lines:
+            try: f.write(f'{line}\n')
+            except: failed.append(line)
+    if failed!=[]:
+        logger.info(f'Failed to write {len(failed)} lines out of {len(lines)}')
+        return failed
+
 '''108 ways to orgasm
 * Walk on soil
 * Drink clean water, eyes closed and sitting
